====================
Administration guide
====================

In this section, you will find documentation relevant for administering
and operating Designate.

Contents:

.. toctree::
   :maxdepth: 1

   tlds
   backends/index
   ha
   pools
   pool-scheduler
   multiple-pools
   blacklists
   quotas
   policy
   config
   notifications
   production-guidelines
   upgrades/index
   troubleshooting
   samples/index
   support-matrix

